@@ -35,11 +35,13 @@
 /* we exclude shift, GDK_CONTROL_MASK and GDK_MOD1_MASK since we know what
    these modifiers mean
    these are the mods whose combinations are bound by the keygrabbing code */
-#define GSD_IGNORED_MODS (0x2000 /*Xkb modifier*/ | GDK_LOCK_MASK  | \
-        GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK)
+#define GSD_IGNORED_MODS (0x2000 /*Xkb modifier*/ | GDK_LOCK_MASK | GDK_HYPER_MASK)
+
 /* these are the ones we actually use for global keys, we always only check
  * for these set */
-#define GSD_USED_MODS (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK)
+#define GSD_USED_MODS (GDK_SHIFT_MASK | GDK_CONTROL_MASK |\
+		       GDK_MOD1_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK |\
+		       GDK_MOD5_MASK | GDK_SUPER_MASK | GDK_META_MASK)
 
 
 static gboolean
@@ -153,7 +155,6 @@ have_xkb (Display *dpy)
 gboolean
 match_key (Key *key, XEvent *event)
 {
-	GdkKeymap *keymap;
 	guint keyval;
 	GdkModifierType consumed;
 	gint group;
@@ -161,26 +162,29 @@ match_key (Key *key, XEvent *event)
 	if (key == NULL)
 		return FALSE;
 
-	keymap = gdk_keymap_get_default ();
+#ifdef HAVE_X11_EXTENSIONS_XKB_H
 	if (have_xkb (event->xkey.display))
 		group = XkbGroupForCoreState (event->xkey.state);
 	else
+#endif
 		group = (event->xkey.state & GDK_Mode_switch) ? 1 : 0;
+
 	/* Check if we find a keysym that matches our current state */
-	if (gdk_keymap_translate_keyboard_state (keymap, event->xkey.keycode,
+	if (gdk_keymap_translate_keyboard_state (NULL, event->xkey.keycode,
 					     event->xkey.state, group,
 					     &keyval, NULL, NULL, &consumed)) {
 		guint lower, upper;
 
 		gdk_keyval_convert_case (keyval, &lower, &upper);
 
-		/* If we don't have different keysyms depending on the
-		 * shift state, remove the shift state from the consumed */
-		if (upper == lower)
+		/* If we are checking against the lower version of the
+		 * keysym, we might need the Shift state for matching,
+		 * so remove it from the consumed modifiers */
+		if (lower == key->keysym)
 			consumed &= ~GDK_SHIFT_MASK;
 
 		return ((lower == key->keysym || upper == key->keysym)
-			&& (key->state & ~consumed & GSD_USED_MODS) == key->state);
+			&& (event->xkey.state & ~consumed & GSD_USED_MODS) == key->state);
 	}
 
 	/* The key we passed doesn't have a keysym, so try with just the keycode */
